A Reddit Post About A Fake Ebola-Like Illness Sparked Panic In Arizona
Author: UPROXX Media
Description: A seemingly benign Reddit post sparked a minor panic in an Arizona town over a fake viral illness.
Keywords: reddit, post, fake, ebola, illness, panic, arizona

Sign Up | Sign In
Bizzy Crook Surprises On 'Coming To America' Mixtape
Salma Hayek Becomes Jane Wick In The Hilariously Violent Trailer For '...

# A Reddit Post About A Fake Ebola-Like Illness Sparked A Panic In And Around An Arizona Town

By Jason Tabrys • 12.29.14

Share This Video

It may seem old fashioned, but I sometimes view the internet and the real world as two separate places. Because of that, it seems weird to me when I see something as typically impact-free as a Reddit post have a very real effect on a small town, but that’s exactly what happened to the town of Mammoth, Arizona after a fictional post got taken literally.

> On the social media site Reddit, a user who goes by the name Lindsey posted a story about an Ebola-like illness taking over the small town.

> “Eleven days ago, on the 3rd, an older woman who runs a home daycare in my town was found dead in her bathroom by a parent who was picking up his daughter,” Lindsey wrote. “The kids were all really agitated and told police that Mrs. Booker (the deceased) had been yelling at them and bleeding from her eye before she went into the bathroom and collapsed in her bathtub.”

> Lindsey goes on to say children began dying, then it spread to others around Mammoth. She said everyone who passed away experienced similar symptoms.

> Adding to the panic, Lindsey wrote: “To the person calling businesses here: that is not us answering. Our downtown has been shut down all day. I called a couple places where I know the business owners and employees and the people who answered are not locals. I don’t know what they told you but they’re not from here.”

> She said it was a cover-up to keep the sickness contained. But, Lindsey was about to fall victim: “I noticed a small bruise on my arm that upon further f***ing inspection spreads all the way down one side of my back. I’m so f***ing scared. I had a breakdown where I just screamed at the wall and cried and there was blood in my tears and that was like an hour ago.”

> She said she needed help, and with the exposure of 1.4 million Reddit users, she got the attention she needed.

Apparently Lindsey’s posts were so well constructed that people called residents in the town to see what was up and the 911 dispatcher was inundated. Folks in the comment section also began to corroborate and expound upon the claims.

Curious about the inadvertent internet firestarter behind this? Here’s an excerpt from an email interview that the local ABC affiliate did with C.K. Walker aka “Lindsey”, the person who started the story.

> “We received mixed reactions. Some people thought it was provocative and interesting – others got upset and called us “terrorists”. This really only happened because the story went viral – those who are a part of the forum know that everything posted in it is fiction; it’s actually noted on the sidebar. When it made it outside of Reddit, people didn’t bother to research the website the stories were posted on and that’s when things went downhill.

> Also, suspension of disbelief is a requirement for the website and any comments debunking the story were deleted for breaking the rules. This just added to the immersion and eventually things got out of control.

> There was a sort of perfect storm that occurred when not only were people in the comments playing along quite convincingly but also that there were, for unknown reasons, actual roadblocks set up on the 77 (from what I was told).”

So, what have we learned? F*ck if I know. These are either terrifying times or a time when the things that terrify us are constantly shown in a loop on a screen that is constantly in front of our faces. That means that people’s freak-out button is a bit more accessible than usual. It’s not good to hit that button, but it’s ultimately not the writer’s fault that people didn’t check to see what was at the heart of this minor panic.

Really, the only defense against something like this is a more diligent inspection of things before we react to them (which would seem to defy our reflexive nature), or a heartier application of skepticism. The former is more time consuming than the latter but we also shouldn’t get to a point where we roll our eyes whenever someone says that they saw a wolf. Cause wolves, man. They out there.

Share This

Source: KGUN 9

TAGS Ebola Internet Panic Mammoth REDDIT

#### Join The Discussion

- Sign In With
- Sign In With Twitter
- Sign In With Email

Profile
5 comments
Jason Tabrys posted

"A Reddit Post About A Fake Ebola-Like Illness Sparked A Panic In And Around An Arizona Town"

1. Profile
   12.29.14 at 9:14 pm
   SatanHimself

   “…an Arizona town”.

   Nope, don’t even need to read this article to figure out what probably happened.

2. Profile
   12.29.14 at 9:15 pm
   stevehandjobs

   Jesus.
   People are morons.

3. Profile
   12.29.14 at 9:52 pm
   Lolba

   pretty soon all this creative shit on the internet gonna be illegal, like yelling ‘fire’ in a crowded theatre. mark my words.

4. Profile
   12.30.14 at 2:12 am
   WTFkid

   Fuck Reddit.

5. Profile
   12.30.14 at 12:01 pm
   Phyllis Rivers

   I’m surprised that hillbillies even know about Reddit.

   #thanksobama

Join the discussion. Sign In or Register

You must be logged in to comment.
Do you like UPROXX?
RSS Feed
Jobs at UPROXX | Contact | Advertising | The UPROXX Team | Terms of Use | Copyright Notices | Privacy Policy
Powered by WordPress.com VIP
Powered by the Parse.ly Publisher Platform (P3).